@@ -302,6 +302,9 @@ def office_activemime(f):
     if f.contents.startswith((b"QWN0aXZlTWltZQ", b"ActiveMime")):
         return "doc"
 
+def msix(f):
+    if f.get_child(b"Registry.dat") and f.get_child(b"AppxManifest.xml"):
+        return "msix"
 
 def office_zip(f):
     if not f.get_child(b"[Content_Types].xml"):
@@ -528,6 +531,7 @@ def identify(f, check_shellcode: bool = False):
 identifiers = [
     udf,
     dmg,
+    msix,
     office_zip,
     office_ole,
     office_one,
